Lorelei
-------

Lorelei is what I would call a "MUD++".

This is a game client which connects to an authoratative game server to provide a visual representation of an entirely text based world. You control a hero with stats, and equipment in a big constantly updated world.

This project was made using pygame as a user interface, and twisted as the networking library. Essentially this gave me the power to easily build a project structure from scratch that allows for easily serializing and deserializing objects over the network between the server and the client.

The Server is closed source to prevent malicious attacks on the game. However the client and library source may be released at some point.


Current Progress
----------------
#. Login / Account creation (DONE)

#. Character Creation (When a new account is made)

   #. Players can select race/class (DONE)

   #. Saves the created character and can load it back (DONE)

#. Making a Basic World space

   #. Players can see/talk to each other

   #. Players can move between rooms

#. Adding more interaction

   #. Players can pickup/drop items

   #. Players can do basic combat (No skills included yet)

#. Create more monsters / items

#. Create more detailed classes / skills





Changelog
---------

::
 0.1.6.6
 Changes:
 * Made this readme

 0.1.6.5
 Changes:
 * Finished saving/loading of the character (including equipment/inventory)
 * Added logic around login to determine if you have a character
   * If not you will be given the character creation screen
   * Otherwise you will enter the main game screen (WIP)